@@ -34,7 +34,7 @@ HOUSE_NO_EXP4 = "((?:^|,|^.+ )((\d{1,3})[/ ]\d{1,3})[ ,]+)\w"
 HOUSE_NO_EXP5 = "((?:^|,|^.+ )(?:No(?:\.|\. | ))?(\d{1,4})[ ,]+)\w"
 VILLAGE_EXP = "(?i)(?:^|,| )(?:หมู่ที่|หมู่ที่|หมู่|ม .|ม.|Moo|Mu)\s?(\d+)"
 ROAD_EXP1 = "(?i)(?:^|,| )(?:(Soi [A-Za-z\- ]+(?: \d{1,4})?)|((?:ซอย|ถนน) [^ ]+(?: \d{1,4})?)|((?:ถ |ถ|ชบ)\.[^ ]+(?: \d{1,4})?))(?: |,|$)"
-ROAD_EXP2 = "(?i)(?:^|(?:[^A-Za-z\-\. ]))([A-Za-z\-\. ]+ (?:\d{1,4} )?(?:Soi|Road|Raod|Rd\.?|Highway|Alley)(?: \d{1,4})?)(?: |,|$)"
+ROAD_EXP2 = "(?i)(?:^|(?:[^A-Za-z\-\. ]))([A-Za-z\-\. ]+ (?:\d{1,4} )?(?:Soi|Road|Raod|Rd\.?|Highway|Route|Alley)(?: \d{1,4})?)(?: |,|$)"
 
 
 def load_thai_admin_areas(dir_path):
@@ -632,6 +632,8 @@ def match_thai_vendor_addresses(customer_address, vendor_addresses, text_dist_th
                 if (vendor_comp["admin_lv2"] == cust_comp["admin_lv2"]) and (vendor_comp["house_no"] == cust_comp["house_no"]):
                     if (cust_comp["street"] is not None) and (cust_comp["street"] == vendor_comp["street"]):
                         pinpoint_sim[i] = 0.99
+                    elif (cust_comp["moo_no"] is not None) and (cust_comp["moo_no"] == vendor_comp["moo_no"]):
+                        pinpoint_sim[i] = 0.96
                     else:
                         pinpoint_sim[i] = textdistance.jaro_winkler(cust_addr_text_upper, vendor_addr_text_upper)
                 else:
